'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var util = require('./util');
var performance = require('./performance');

var INFO = 'info';
var PERF = 'addPerfData';

var TIME_POOL = {};
module.exports = function () {
  function Pharos(site_id, host) {
    var opt = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    _classCallCheck(this, Pharos);

    this.site_id = site_id;
    this.host = host;
    this[INFO] = {
      screen: global.screen.width + 'x' + global.screen.height
    };
    this[PERF] = this.addPerf();

    this.listenError(opt);
  }

  _createClass(Pharos, [{
    key: 'listenError',
    value: function listenError(_ref) {
      var _this = this;

      var onError = _ref.onError;

      if (!global.addEventListener) {
        return;
      }

      global.addEventListener('error', function (err) {
        if (!err) return;

        var message = err.error && err.error.stack || err.message;
        if (typeof onError === 'function') {
          message = onError(err);
        }
        if (!message) return;
        _this.send({ errmsg: message });
      });

      global.addEventListener('unhandledrejection', function (reject) {
        if (!reject) return;

        var message = reject.reason;
        if (message instanceof Error) {
          message = message.error && message.error.stack || message.message;
        }

        if (typeof onError === 'function') {
          message = onError(reject);
        }
        if (!message) return;
        _this.send({ errmsg: message });
      });
    }
  }, {
    key: 'addPerf',
    value: function addPerf() {
      var _this2 = this;

      return new Promise(function (resolve) {
        return global.addEventListener('load', function () {
          return setTimeout(function () {
            _this2.add(performance());
            resolve();

            _this2[PERF] = Promise.resolve();
          });
        });
      });
    }
  }, {
    key: 'monitor',
    value: function monitor(info) {
      var _this3 = this;

      return this[PERF].then(function () {
        return _this3.send(info);
      });
    }
  }, {
    key: 'send',
    value: function send() {
      var info = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this[INFO];

      var host = this.host;
      if (!/^(http|\/\/)/i.test(host)) {
        host = location.protocol + '//' + host;
      }

      var baseUrl = host + '/pharos.gif?';
      var params = { site_id: this.site_id };
      for (var k in info) {
        params[k] = info[k];
      }
      util.sendLog(baseUrl + util.build_query(params));

      this.clear();
    }
  }, {
    key: 'time',
    value: function time(name) {
      TIME_POOL[name] = Date.now();
    }
  }, {
    key: 'timeEnd',
    value: function timeEnd(name) {
      var now = Date.now();
      if (!TIME_POOL[name]) {
        TIME_POOL[name] = now;
      }

      var delta = now - TIME_POOL[name];
      this.add(name, delta);
      // eslint-disable-next-line no-console
      console.log(name + ': ' + delta + 'ms');
      delete TIME_POOL[name];
    }
  }, {
    key: 'add',
    value: function add(key, val) {
      var data = key;
      if (util.isNumber(val)) {
        data = _defineProperty({}, key, val);
      }

      for (var k in data) {
        if (!util.isNumber(data[k])) {
          continue;
        }
        this[INFO][k] = data[k];
      }
      return true;
    }
  }, {
    key: 'delete',
    value: function _delete() {
      for (var _len = arguments.length, infoKeys = Array(_len), _key = 0; _key < _len; _key++) {
        infoKeys[_key] = arguments[_key];
      }

      for (var i = 0; i < infoKeys.length; i++) {
        delete this[INFO][infoKeys[i]];
      }
      return true;
    }
  }, {
    key: 'clear',
    value: function clear() {
      var data = {};
      for (var k in this[INFO]) {
        data[k] = this[INFO][k];
        this.delete(k);
      }
      return data;
    }
  }, {
    key: 'search',
    value: function search(key) {
      return this[INFO][key];
    }
  }]);

  return Pharos;
}();